@@ -32,7 +32,9 @@ class ModelParserRegistry:
     _parsers: Dict[str, ModelParser] = {}
 
     @staticmethod
-    def register_model_parser(model_parser: ModelParser, ids: Optional[List[str]] = None):
+    def register_model_parser(
+        model_parser: ModelParser, ids: Optional[List[str]] = None
+    ):
         """
         Adds a model parser to the registry. This model parser is used to parse Prompts
         in the AIConfig that use the given model.
@@ -59,6 +61,10 @@ class ModelParserRegistry:
         Returns:
             ModelParser: The retrieved model parser
         """
+        if model_id not in ModelParserRegistry.parser_ids():
+            raise IndexError(
+                f"Model parser '{model_id}' not found in registry, available model parsers are:\n {ModelParserRegistry.parser_ids()}"
+            )
         return ModelParserRegistry._parsers[model_id]
 
     @staticmethod
@@ -108,10 +114,15 @@ class ModelParserRegistry:
         """
         returns a dictionary of model names and their correspondings model parser ids
         """
-        return {model_name: model_parser.id() for model_name, model_parser in ModelParserRegistry._parsers.items()}
+        return {
+            model_name: model_parser.id()
+            for model_name, model_parser in ModelParserRegistry._parsers.items()
+        }
 
 
-def update_model_parser_registry_with_config_runtime(config_runtime: "AIConfigRuntime"):
+def update_model_parser_registry_with_config_runtime(
+    config_runtime: "AIConfigRuntime",
+):
     """
     Updates the model parser registry with any model parsers specified in the AIConfig.
 
@@ -120,8 +131,13 @@ def update_model_parser_registry_with_config_runtime(config_runtime: "AIConfigRu
     """
     if not config_runtime.metadata.model_parsers:
         return
-    for model_id, model_parser_id in config_runtime.metadata.model_parsers.items():
-        retrieved_model_parser = ModelParserRegistry.get_model_parser(model_parser_id)  # Fix
+    for (
+        model_id,
+        model_parser_id,
+    ) in config_runtime.metadata.model_parsers.items():
+        retrieved_model_parser = ModelParserRegistry.get_model_parser(
+            model_parser_id
+        )  # Fix
         if retrieved_model_parser is None:
             error_message = (
                 f"Unable to load AIConfig: It specifies {config_runtime.metadata.model_parsers}, "
@@ -131,4 +147,6 @@ def update_model_parser_registry_with_config_runtime(config_runtime: "AIConfigRu
             )
             raise Exception(error_message)
 
-        ModelParserRegistry.register_model_parser(retrieved_model_parser, [model_id])
+        ModelParserRegistry.register_model_parser(
+            retrieved_model_parser, [model_id]
+        )
